@@ -39,9 +39,9 @@ public:
     Block(HalDevice *device);
     virtual ~Block();
 
-    int deviceMajor() const Q_DECL_OVERRIDE;
-    int deviceMinor() const Q_DECL_OVERRIDE;
-    QString device() const Q_DECL_OVERRIDE;
+    int deviceMajor() const override;
+    int deviceMinor() const override;
+    QString device() const override;
 };
 }
 }
